@@ -2,25 +2,30 @@ from __future__ import annotations
 
 import libcst
 
+from slyp.hashable_file import HashableFile
+
+from ._base import ErrorCollectingVisitor
 from .str_concat import StrConcatErrorCollector
 
-_VISITORS = [StrConcatErrorCollector()]
+_VISITORS: list[ErrorCollectingVisitor] = [
+    StrConcatErrorCollector(),
+]
 
 
-def run_cst_checkers(filename: str, content: bytes) -> set[tuple[int, str]]:
+def run_cst_checkers(file_obj: HashableFile) -> set[tuple[int, str]]:
     try:
-        tree = libcst.parse_module(content)
-    except libcst.ParserSyntaxError:
+        tree = libcst.parse_module(file_obj.binary_content)
+    except (libcst.ParserSyntaxError, libcst.CSTValidationError):
         return {(0, "X001")}
     wrapper = libcst.MetadataWrapper(tree)
     for visitor in _VISITORS:
-        visitor.filename = filename
+        visitor.filename = file_obj.filename
         wrapper.visit(visitor)
     return {
         (lineno, code)
-        for (lineno, error_filename, code) in visitor.errors
-        if error_filename == filename
         for visitor in _VISITORS
+        for (lineno, error_filename, code) in visitor.errors
+        if error_filename == file_obj.filename
     }
 
 
